OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "%s 님에게 메일을 보낼 수 없습니다.",
    "Preparing update" : "업데이트 준비 중",
    "Turned on maintenance mode" : "유지 보수 모드 켜짐",
    "Turned off maintenance mode" : "유지 보수 모드 꺼짐",
    "Maintenance mode is kept active" : "유지 보수 모드가 켜져 있음",
    "Updating database schema" : "데이터베이스 스키마 업데이트 중",
    "Updated database" : "데이터베이스 업데이트 됨",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
    "Checked database schema update" : "데이터베이스 스키마 업데이트 확인됨",
    "Checking updates of apps" : "앱 업데이트 확인 중",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s의 데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
    "Checked database schema update for apps" : "앱용 데이터베이스 스키마 업데이트 확인됨",
    "Updated \"%s\" to %s" : "\"%s\"을(를) %s(으)로 업데이트함",
    "Repair warning: " : "수리 경고:",
    "Repair error: " : "수리 오류:",
    "%s (3rdparty)" : "%s(제 3사)",
    "%s (incompatible)" : "%s(호환 불가)",
    "Following apps have been disabled: %s" : "다음 앱이 비활성화되었습니다: %s",
    "Already up to date" : "최신 상태임",
    "File is too big" : "파일이 너무 큼",
    "Invalid file provided" : "잘못된 파일 지정됨",
    "No image or file provided" : "사진이나 파일이 없음",
    "Unknown filetype" : "알려지지 않은 파일 형식",
    "Invalid image" : "잘못된 사진",
    "An error occurred. Please contact your admin." : "오류가 발생했습니다. 시스템 관리자에게 연락하십시오.",
    "No temporary profile picture available, try again" : "사용 가능한 프로필 사진이 없습니다. 다시 시도하십시오.",
    "No crop data provided" : "선택된 데이터가 없습니다.",
    "No valid crop data provided" : "올바른 잘라내기 데이터가 지정되지 않음",
    "Crop is not square" : "잘라내는 영역이 사각형이 아님",
    "Couldn't reset password because the token is invalid" : "토큰이 잘못되었기 때문에 암호를 초기화할 수 없습니다",
    "Couldn't reset password because the token is expired" : "토큰이 만료되어 암호를 초기화할 수 없습니다",
    "Couldn't send reset email. Please make sure your username is correct." : "재설정 메일을 보낼 수 없습니다. 사용자 이름이 올바른지 확인하십시오.",
    "%s password reset" : "%s 암호 재설정",
    "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼수 없습니다. 관리자에게 문의하십시오.",
    "Sunday" : "일요일",
    "Monday" : "월요일",
    "Tuesday" : "화요일",
    "Wednesday" : "수요일",
    "Thursday" : "목요일",
    "Friday" : "금요일",
    "Saturday" : "토요일",
    "Sun." : "일",
    "Mon." : "월",
    "Tue." : "화",
    "Wed." : "수",
    "Thu." : "목",
    "Fri." : "금",
    "Sat." : "토",
    "Su" : "일",
    "Mo" : "월",
    "Tu" : "화",
    "We" : "수",
    "Th" : "목",
    "Fr" : "금",
    "Sa" : "토",
    "January" : "1월",
    "February" : "2월",
    "March" : "3월",
    "April" : "4월",
    "May" : "5월",
    "June" : "6월",
    "July" : "7월",
    "August" : "8월",
    "September" : "9월",
    "October" : "10월",
    "November" : "11월",
    "December" : "12월",
    "Jan." : "1월",
    "Feb." : "2월",
    "Mar." : "3월",
    "Apr." : "4월",
    "May." : "5월",
    "Jun." : "6월",
    "Jul." : "7월",
    "Aug." : "8월",
    "Sep." : "9월",
    "Oct." : "10월",
    "Nov." : "11월",
    "Dec." : "12월",
    "Settings" : "설정",
    "Saving..." : "저장 중...",
    "Dismiss" : "닫기",
    "seconds ago" : "초 지남",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "암호 재설정 링크를 포함하고 있는 이메일을 보냈습니다. 이메일이 도착하지 않은 경우 스팸함을 확인해 보십시오.<br>스팸함에도 없는 경우 로컬 관리자에게 문의하십시오.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "파일이 암호화되어 있습니다. 복구 키를 활성화하지 않았다면 암호를 초기화한 후 데이터를 복구할 수 없습니다.<br />무엇을 해야 할 지 잘 모르겠으면 계속하기 전에 관리자에게 연락하십시오.<br />그래도 계속 진행하시겠습니까?",
    "I know what I'm doing" : "지금 하려는 것을 알고 있습니다",
    "Password can not be changed. Please contact your administrator." : "암호를 변경할 수 없습니다. 관리자에게 문의하십시오.",
    "No" : "아니요",
    "Yes" : "예",
    "Choose" : "선택",
    "Error loading file picker template: {error}" : "파일 선택 템플릿을 불러오는 중 오류 발생: {error}",
    "Ok" : "확인",
    "Error loading message template: {error}" : "메시지 템플릿을 불러오는 중 오류 발생: {error}",
    "read-only" : "읽기 전용",
    "_{count} file conflict_::_{count} file conflicts_" : ["파일 {count}개 충돌"],
    "One file conflict" : "파일 1개 충돌",
    "New Files" : "새 파일",
    "Already existing files" : "파일이 이미 존재합니다",
    "Which files do you want to keep?" : "어느 파일을 유지하시겠습니까?",
    "If you select both versions, the copied file will have a number added to its name." : "두 버전을 모두 선택하면, 파일 이름에 번호가 추가될 것입니다.",
    "Cancel" : "취소",
    "Continue" : "계속",
    "(all selected)" : "(모두 선택됨)",
    "({count} selected)" : "({count}개 선택됨)",
    "Error loading file exists template" : "파일 존재함 템플릿을 불러오는 중 오류 발생",
    "Very weak password" : "매우 약한 암호",
    "Weak password" : "약한 암호",
    "So-so password" : "그저 그런 암호",
    "Good password" : "좋은 암호",
    "Strong password" : "강력한 암호",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "WebDAV 서비스가 올바르게 작동하지 않아서 웹 서버에서 파일 동기화를 사용할 수 없습니다.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "서버에서 인터넷 연결을 사용할 수 없습니다. 외부 저장소 마운트, 업데이트 알림, 제 3자 앱 설치 등 기능을 사용할 수 없습니다. 원격에서 파일에 접근하거나, 알림 이메일을 보내지 못할 수도 있습니다. 모든 기능을 사용하려면 인터넷에 연결하는 것을 추천합니다.",
    "Error occurred while checking server setup" : "서버 설정을 확인하는 중 오류 발생",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "인터넷에서 데이터 디렉터리와 파일에 접근할 수 있습니다. .htaccess 파일이 작동하지 않습니다. 웹 서버 설정을 변경하여 데이터 디렉터리에 직접 접근할 수 없도록 하거나, 데이터 디렉터리를 웹 서버 문서 경로 바깥에 두십시오.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP 헤더가 \"{expected}\"와(과) 같이 설정되지 않았습니다. 잠재적인 보안 위협이 될 수 있으므로 설정을 변경하는 것을 추천합니다.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "이 사이트를 HTTP로 접근하고 있습니다. <a href=\"{docUrl}\">보안 팁</a>에 나타난 것처럼 서버 설정을 변경하여 HTTPS를 사용하는 것을 강력히 추천합니다.",
    "Shared" : "공유됨",
    "Shared with {recipients}" : "{recipients} 님과 공유됨",
    "Error" : "오류",
    "Error while sharing" : "공유하는 중 오류 발생",
    "Error while unsharing" : "공유 해제하는 중 오류 발생",
    "Error setting expiration date" : "만료 날짜 설정 오류",
    "The public link will expire no later than {days} days after it is created" : "공개 링크를 만든 후 최대 {days}일까지 유지됩니다",
    "Set expiration date" : "만료 날짜 설정",
    "Expiration" : "만료",
    "Expiration date" : "만료 날짜",
    "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
    "Sending ..." : "전송 중...",
    "Email sent" : "이메일 발송됨",
    "Resharing is not allowed" : "다시 공유할 수 없습니다",
    "Share link" : "링크 공유",
    "Link" : "링크",
    "Password protect" : "암호 보호",
    "Password" : "암호",
    "Allow editing" : "편집 허용",
    "Email link to person" : "이메일 주소",
    "Send" : "전송",
    "Shared with you and the group {group} by {owner}" : "{owner} 님이 여러분 및 그룹 {group}와(과) 공유 중",
    "Shared with you by {owner}" : "{owner} 님이 공유 중",
    "group" : "그룹",
    "remote" : "원격",
    "notify by email" : "이메일로 알림",
    "Unshare" : "공유 해제",
    "can share" : "공유 가능",
    "can edit" : "편집 가능",
    "create" : "생성",
    "change" : "변경",
    "delete" : "삭제",
    "access control" : "접근 제어",
    "Share details could not be loaded for this item." : "이 항목의 공유 정보를 불러올 수 없습니다.",
    "An error occured. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
    "Share" : "공유",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "username@example.com/owncloud 형식으로 다른 ownCloud 사용자와 공유할 수 있습니다",
    "Share with users or groups …" : "사용자 및 그룹과 공유...",
    "Share with users, groups or remote users …" : "사용자, 그룹 및 원격 사용자와 공유...",
    "Warning" : "경고",
    "Error while sending notification" : "알림을 보내는 중 오류 발생",
    "Delete" : "삭제",
    "Rename" : "이름 바꾸기",
    "The object type is not specified." : "객체 유형이 지정되지 않았습니다.",
    "Enter new" : "새로운 값 입력",
    "Add" : "추가",
    "Edit tags" : "태그 편집",
    "Error loading dialog template: {error}" : "대화 상자 템플릿을 불러오는 중 오류 발생: {error}",
    "No tags selected for deletion." : "삭제할 태그를 선택하지 않았습니다.",
    "unknown text" : "알 수 없는 텍스트",
    "Hello world!" : "Hello world!",
    "sunny" : "맑음",
    "Hello {name}, the weather is {weather}" : "{name} 님 안녕하세요, 오늘 날씨는 {weather}입니다",
    "Hello {name}" : "{name} 님 안녕하세요",
    "_download %n file_::_download %n files_" : ["파일 %n개 다운로드"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "업그레이드 중입니다. 이 페이지를 열어 두면 일부 환경에서 진행 과정을 중단시킬 수 있습니다.",
    "Updating {productName} to version {version}, this may take a while." : "{productName}을(를) 버전 {version}으로 업데이트하고 있습니다. 시간이 걸릴 수 있습니다.",
    "An error occurred." : "오류가 발생했습니다.",
    "Please reload the page." : "페이지를 새로 고치십시오.",
    "The update was unsuccessful. " : "업데이트가 실패했습니다. ",
    "The update was successful. There were warnings." : "업데이트가 성공했습니다. 일부 경고가 있습니다.",
    "The update was successful. Redirecting you to ownCloud now." : "업데이트가 성공했습니다. ownCloud로 돌아갑니다.",
    "Searching other places" : "다른 장소 찾는 중",
    "No search results in other folders" : "다른 폴더에 검색 결과 없음",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["다른 폴더의 검색 결과 {count}개"],
    "Personal" : "개인",
    "Users" : "사용자",
    "Apps" : "앱",
    "Admin" : "관리자",
    "Help" : "도움말",
    "Error loading tags" : "태그 불러오기 오류",
    "Tag already exists" : "태그가 이미 존재합니다",
    "Error deleting tag(s)" : "태그 삭제 오류",
    "Error tagging" : "태그 추가 오류",
    "Error untagging" : "태그 해제 오류",
    "Error favoriting" : "즐겨찾기 추가 오류",
    "Error unfavoriting" : "즐겨찾기 삭제 오류",
    "Access forbidden" : "접근 금지됨",
    "File not found" : "파일을 찾을 수 없음",
    "The specified document has not been found on the server." : "지정한 문서를 서버에서 찾을 수 없습니다.",
    "You can click here to return to %s." : "%s(으)로 돌아가려면 여기를 누르십시오.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "안녕하세요,\n\n%s 님이 %s을(를) 공유하였음을 알려 드립니다.\n보기 링크: %s\n\n",
    "The share will expire on %s." : "이 공유는 %s 까지 유지됩니다.",
    "Cheers!" : "감사합니다!",
    "Internal Server Error" : "내부 서버 오류",
    "The server encountered an internal error and was unable to complete your request." : "서버에 내부 오류가 발생하여 요청을 처리할 수 없었습니다.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "이 오류가 여러 번 발생한다면 서버 관리자에게 연락해 주시고, 아래 기술적인 정보를 포함해 주십시오.",
    "More details can be found in the server log." : "서버 로그에서 자세한 정보를 찾을 수 있습니다.",
    "Technical details" : "기술 정보",
    "Remote Address: %s" : "원격 주소: %s",
    "Request ID: %s" : "요청 ID: %s",
    "Type: %s" : "종류: %s",
    "Code: %s" : "코드: %s",
    "Message: %s" : "메시지: %s",
    "File: %s" : "파일: %s",
    "Line: %s" : "줄: %s",
    "Trace" : "추적",
    "Security warning" : "보안 경고",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess 파일이 처리되지 않아서 데이터 디렉터리와 파일을 인터넷에서 접근할 수 없을 수도 있습니다.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "올바른 서버 설정을 위한 정보는 <a href=\"%s\" target=\"_blank\">문서</a>를 참조하십시오.",
    "Create an <strong>admin account</strong>" : "<strong>관리자 계정</strong> 만들기",
    "Username" : "사용자 이름",
    "Storage & database" : "저장소 및 데이터베이스",
    "Data folder" : "데이터 폴더",
    "Configure the database" : "데이터베이스 설정",
    "Only %s is available." : "%s만 사용 가능합니다.",
    "Install and activate additional PHP modules to choose other database types." : "다른 데이터베이스 종류를 사용하려면 추가 PHP 모듈을 설치 및 활성화하십시오.",
    "For more details check out the documentation." : "자세한 정보를 보려면 문서를 참고하십시오.",
    "Database user" : "데이터베이스 사용자",
    "Database password" : "데이터베이스 암호",
    "Database name" : "데이터베이스 이름",
    "Database tablespace" : "데이터베이스 테이블 공간",
    "Database host" : "데이터베이스 호스트",
    "Performance warning" : "성능 경고",
    "SQLite will be used as database." : "데이터베이스로 SQLite를 사용하게 됩니다.",
    "For larger installations we recommend to choose a different database backend." : "대규모의 파일을 관리하려고 한다면 다른 데이터베이스 백엔드를 선택할 것을 권장합니다.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정일 때는, SQLite를 사용하지 않는 것이 좋습니다.",
    "Finish setup" : "설치 완료",
    "Finishing …" : "완료 중 ...",
    "Need help?" : "도움이 필요한가요?",
    "See the documentation" : "문서 보기",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "안녕하세요,<br><br>%s 님이 <strong>%s</strong>을(를) 공유하였음을 알려 드립니다.<br><a href=\"%s\">보러 가기!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "이 프로그램이 올바르게 작동하려면 JavaScript가 필요합니다. {linkstart}JavaScript를 활성화{linkend}한 다음 페이지를 새로 고치십시오.",
    "Log out" : "로그아웃",
    "Search" : "검색",
    "Server side authentication failed!" : "서버 인증 실패!",
    "Please contact your administrator." : "관리자에게 문의하십시오.",
    "An internal error occured." : "내부 오류가 발생했습니다.",
    "Please try again or contact your administrator." : "다시 시도하거나 관리자에게 연락하십시오.",
    "Log in" : "로그인",
    "Wrong password. Reset it?" : "암호가 잘못되었습니다. 다시 설정하시겠습니까?",
    "Stay logged in" : "로그인 유지",
    "Alternative Logins" : "대체 로그인",
    "Use the following link to reset your password: {link}" : "다음 링크를 사용하여 암호를 재설정할 수 있습니다: {link}",
    "New password" : "새 암호",
    "New Password" : "새 암호",
    "Reset password" : "암호 재설정",
    "This ownCloud instance is currently in single user mode." : "ownCloud 인스턴스가 현재 단일 사용자 모드로 동작 중입니다.",
    "This means only administrators can use the instance." : "현재 시스템 관리자만 인스턴스를 사용할 수 있습니다.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나, 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오",
    "Thank you for your patience." : "기다려 주셔서 감사합니다.",
    "You are accessing the server from an untrusted domain." : "신뢰할 수 없는 도메인으로 서버에 접근하고 있습니다.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "설정에 따라서 관리자 권한으로 아래 단추를 눌러서 이 도메인을 신뢰하도록 설정할 수 있습니다.",
    "Add \"%s\" as trusted domain" : "\"%s\"을(를) 신뢰할 수 있는 도메인으로 추가",
    "App update required" : "앱 업데이트 필요",
    "%s will be updated to version %s" : "%s 앱을 버전 %s(으)로 업데이트합니다",
    "These apps will be updated:" : "다음 앱을 업데이트합니다:",
    "These incompatible apps will be disabled:" : "다음 호환되지 않는 앱이 비활성화됩니다:",
    "The theme %s has been disabled." : "%s 테마가 비활성화되었습니다.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "계속하기 전에 데이터베이스, 설정 폴더, 데이터 폴더가 백업되어 있는지 확인하십시오.",
    "Start update" : "업데이트 시작",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "큰 파일을 설치하는 경우 시간이 초과될 수 있으므로, 설치 디렉터리에서 다음 명령을 실행하셔도 됩니다:",
    "This %s instance is currently in maintenance mode, which may take a while." : "이 %s 인스턴스는 현재 점검 모드입니다. 시간이 걸릴 수도 있습니다.",
    "This page will refresh itself when the %s instance is available again." : "%s 인스턴스를 다시 사용할 수 있으면 자동으로 새로 고칩니다."
},
"nplurals=1; plural=0;");
